Learn R Programming

hypothesize (version 0.11.0)

hypothesize-package: hypothesize: Consistent API for Hypothesis Testing

Description

Provides a consistent API for hypothesis testing built on principles from 'Structure and Interpretation of Computer Programs': data abstraction, closure (combining tests yields tests), and higher-order functions (transforming tests). Implements z-tests, Wald tests, likelihood ratio tests, Fisher's method for combining p-values, and multiple testing corrections. Designed for use by other packages that want to wrap their hypothesis tests in a consistent interface.

Arguments

Author

Maintainer: Alexander Towell lex@metafunctor.com (ORCID)

See Also