Check if a hypothesis test is significant at a given level

is_significant_at(x, alpha, ...)

# S3 method for class 'hypothesis_test'
is_significant_at(x, alpha, ...)

Arguments

x

a hypothesis test object

alpha

significance level

...

additional arguments passed to methods

Value

Logical indicating whether the test is significant at level alpha.

Examples

w <- wald_test(estimate = 2.5, se = 0.8)
is_significant_at(w, 0.05)
#> [1] TRUE