Learn R Programming

hypothesize (version 0.11.0)

is_significant_at: Check if a hypothesis test is significant at a given level

Description

Check if a hypothesis test is significant at a given level

Usage

is_significant_at(x, alpha, ...)

# S3 method for hypothesis_test is_significant_at(x, alpha, ...)

Value

Logical indicating whether the test is significant at level alpha.

Arguments

x

a hypothesis test object

alpha

significance level

...

additional arguments passed to methods

Examples

Run this code
w <- wald_test(estimate = 2.5, se = 0.8)
is_significant_at(w, 0.05)

Run the code above in your browser using DataLab