powered by
Check if a hypothesis test is significant at a given level
is_significant_at(x, alpha, ...)# S3 method for hypothesis_test is_significant_at(x, alpha, ...)
# S3 method for hypothesis_test is_significant_at(x, alpha, ...)
Logical indicating whether the test is significant at level alpha.
alpha
a hypothesis test object
significance level
additional arguments passed to methods
w <- wald_test(estimate = 2.5, se = 0.8) is_significant_at(w, 0.05)
Run the code above in your browser using DataLab